==> container-service-extension-3.1.0.tar.gz: container-service-extension-3.1.0/docs/cse3_1/TEMPLATE_ANNOUNCEMENTS.md <==
---
layout: default
title: Template Announcements
---
# Template Announcements

## Jul 2, 2021

All templates currently available:
* New templates are highlighted
* Updated template revisions are highlighted
* Removed templates are striked out

| Template Name                        | Revision | Operating System  | Kubernetes  | Weave     | Docker                  |
|--------------------------------------|----------|-------------------|-------------|-----------|-------------------------|
| **ubuntu-16.04_k8-1.21_weave-2.8.1** | 1        | Ubuntu-16.04      | 1.21.2      | 2.8.1     | Docker-ce 20.10.7       |
| ubuntu-16.04_k8-1.20_weave-2.6.5     | **2**    | Ubuntu-16.04      | 1.20.6      | 2.6.5     | Docker-ce 19.03.15      |
| ubuntu-16.04_k8-1.19_weave-2.6.5     | **2**    | Ubuntu-16.04      | 1.19.3      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.18_weave-2.6.5 *   | 2        | Ubuntu-16.04      | 1.18.6      | 2.6.5     | Docker-ce 19.03.12      |
| ~~ubuntu-16.04_k8-1.17_weave-2.6.0~~ | ~~2~~    | ~~Ubuntu 16.04~~  | ~~1.17.9~~  | ~~2.6.0~~ | ~~Docker-ce 19.03.5~~   |
| photon-v2_k8-1.14_weave-2.5.2        | 3        | Photon OS 2.0     | 1.14.10     | 2.5.2     | Docker-ce 18.06.2-6     |

Templates marked with '*' are deprecated and will be removed in future update.

## May 3, 2021

All templates currently available:
* New templates are highlighted
* Updated template revisions are highlighted
* Removed templates are striked out

| Template Name                        | Revision | Operating System  | Kubernetes  | Weave     | Docker                  |
|--------------------------------------|----------|-------------------|-------------|-----------|-------------------------|
| **ubuntu-16.04_k8-1.20_weave-2.6.5** | 1        | Ubuntu-16.04      | 1.20.6      | 2.6.5     | Docker-ce 19.03.15      |
| ubuntu-16.04_k8-1.19_weave-2.6.5     | 1        | Ubuntu-16.04      | 1.19.3      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.18_weave-2.6.5     | 1        | Ubuntu-16.04      | 1.18.6      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.17_weave-2.6.0 *   | 2        | Ubuntu 16.04      | 1.17.9      | 2.6.0     | Docker-ce 19.03.5       |
| ~~ubuntu-16.04_k8-1.16_weave-2.6.0~~ | ~~2~~    | ~~Ubuntu 16.04~~  | ~~1.16.13~~ | ~~2.6.0~~ | ~~Docker-ce 18.09.7~~   |
| photon-v2_k8-1.14_weave-2.5.2        | 3        | Photon OS 2.0     | 1.14.10     | 2.5.2     | Docker-ce 18.06.2-6     |

Templates marked with '*' are deprecated and will be removed in future update.

## December 10, 2020

All templates currently available:
* New templates are highlighted
* Updated template revisions are highlighted
* Removed templates are striked out

| Template Name                        | Revision | Operating System  | Kubernetes  | Weave     | Docker                  |
|--------------------------------------|----------|-------------------|-------------|-----------|-------------------------|
| **ubuntu-16.04_k8-1.19_weave-2.6.5** | 1        | Ubuntu-16.04      | 1.19.3      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.18_weave-2.6.5     | 1        | Ubuntu-16.04      | 1.18.6      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.17_weave-2.6.0     | 2        | Ubuntu 16.04      | 1.17.9      | 2.6.0     | Docker-ce 19.03.5       |
| ubuntu-16.04_k8-1.16_weave-2.6.0 *   | 2        | Ubuntu 16.04      | 1.16.13     | 2.6.0     | Docker-ce 18.09.7       |
| ~~ubuntu-16.04_k8-1.15_weave-2.5.2~~ | ~~4~~    | ~~Ubuntu 16.04~~  | ~~1.15.12~~ | ~~2.5.2~~ | ~~Docker-ce 18.09.7~~   |
| photon-v2_k8-1.14_weave-2.5.2        | 3        | Photon OS 2.0     | 1.14.10     | 2.5.2     | Docker-ce 18.06.2-6     |

Templates marked with '*' are deprecated and will be removed in future update.

## October 08, 2020

All templates currently available:
* New templates are highlighted
* Updated template revisions are highlighted

| Template Name                        | Revision | Operating System  | Kubernetes  | Weave     | Docker                  |
|--------------------------------------|----------|-------------------|-------------|-----------|-------------------------|
| **ubuntu-16.04_k8-1.18_weave-2.6.5** | 1        | Ubuntu-16.04      | 1.18.6      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.17_weave-2.6.0     | **2**    | Ubuntu 16.04      | 1.17.9      | 2.6.0     | Docker-ce 19.03.5       |
| ubuntu-16.04_k8-1.16_weave-2.6.0     | **2**    | Ubuntu 16.04      | 1.16.13     | 2.6.0     | Docker-ce 18.09.7       |
| ubuntu-16.04_k8-1.15_weave-2.5.2 *     | **4**    | Ubuntu 16.04      | 1.15.12     | 2.5.2     | Docker-ce 18.09.7       |
| photon-v2_k8-1.14_weave-2.5.2        | **3**    | Photon OS 2.0     | 1.14.10      | 2.5.2    | Docker-ce 18.06.2-6     |

Templates marked with '*' are deprecated and will be removed in future update.

## March 09, 2020

All templates currently available:
* New templates are highlighted
* Updated template revisions are highlighted
* Removed templates are striked out

| Template Name                        | Revision | Operating System  | Kubernetes  | Weave     | Docker                  |
|--------------------------------------|----------|-------------------|-------------|-----------|-------------------------|
| **ubuntu-16.04_k8-1.17_weave-2.6.0** | 1        | Ubuntu 16.04      | 1.17.2      | 2.6.0     | Docker-ce 18.09.7       |
| **ubuntu-16.04_k8-1.16_weave-2.6.0** | 1        | Ubuntu 16.04      | 1.16.6      | 2.6.0     | Docker-ce 18.09.7       |
| ubuntu-16.04_k8-1.15_weave-2.5.2     | **3**    | Ubuntu 16.04      | 1.15.9      | 2.5.2     | Docker-ce 18.09.7       |
| photon-v2_k8-1.14_weave-2.5.2        | **2**    | Photon OS 2.0     | 1.14.6      | 2.5.2     | Docker-ce 18.06.2-3     |
|                                      |          |                   |             |           |                         |
| ~~ubuntu-16.04_k8-1.13_weave-2.3.0~~ | ~~3~~    | ~~Ubuntu 16.04~~  | ~~1.13.12~~ | ~~2.3.0~~ | ~~Docker-ce 18.09.7~~   |
| ~~photon-v2_k8-1.12_weave-2.3.0~~    | ~~2~~    | ~~Photon OS 2.0~~ | ~~1.12.7~~  | ~~2.3.0~~ | ~~Docker-ce 18.06.2-3~~ |


## February 05, 2020

These templates are exclusively for CSE 2.6.0 Beta.

| Template Name                    | Revision | Operating System | Kubernetes | Weave | Docker              |
|----------------------------------|----------|------------------|------------|-------|---------------------|
| photon-v2_k8-1.14_weave-2.5.2    | 2        | Photon OS 2.0    | 1.14.6     | 2.5.2 | Docker-ce 18.06.2-3 |
| photon-v2_k8-1.12_weave-2.3.0    | 2        | Photon OS 2.0    | 1.12.7     | 2.3.0 | Docker-ce 18.06.2-3 |
| ubuntu-16.04_k8-1.16_weave-2.6.0 | 1        | Ubuntu 16.04     | 1.16.6     | 2.6.0 | Docker-ce 18.09.7   |
| ubuntu-16.04_k8-1.15_weave-2.5.2 | 3        | Ubuntu 16.04     | 1.15.9     | 2.5.2 | Docker-ce 18.09.7   |
| ubuntu-16.04_k8-1.13_weave-2.3.0 | 3        | Ubuntu 16.04     | 1.13.12    | 2.3.0 | Docker-ce 18.09.7   |

## October 23, 2019

All templates currently available (updated/new templates are highlighted):

| Template Name                        | Revision | Operating System | Kubernetes | Weave | Docker              |
|--------------------------------------|----------|------------------|------------|-------|---------------------|
| **photon-v2_k8-1.14_weave-2.5.2**    | 1        | Photon OS 2.0    | 1.14.6     | 2.5.2 | Docker-ce 18.06.2-3 |
| photon-v2_k8-1.12_weave-2.3.0        | 1        | Photon OS 2.0    | 1.12.7     | 2.3.0 | Docker-ce 18.06.2-3 |
| **ubuntu-16.04_k8-1.15_weave-2.5.2** | 2        | Ubuntu 16.04     | 1.15.5     | 2.5.2 | Docker-ce 18.09.7   |
| **ubuntu-16.04_k8-1.13_weave-2.3.0** | 2        | Ubuntu 16.04     | 1.13.12    | 2.3.0 | Docker-ce 18.09.7   |

## October 3, 2019

All templates currently available (updated/new templates are highlighted):

| Template Name                    | Revision | Operating System | Kubernetes | Weave | Docker              |
|----------------------------------|----------|------------------|------------|-------|---------------------|
| photon-v2_k8-1.12_weave-2.3.0    | 1        | Photon OS 2.0    | 1.12.7     | 2.3.0 | Docker-ce 18.06.2-3 |
| ubuntu-16.04_k8-1.15_weave-2.5.2 | 1        | Ubuntu 16.04     | 1.15.3     | 2.5.2 | Docker-ce 18.09.7   |
| ubuntu-16.04_k8-1.13_weave-2.3.0 | 1        | Ubuntu 16.04     | 1.13.5     | 2.3.0 | Docker-ce 18.09.7   |

==> container-service-extension-3.1.4.tar.gz: container-service-extension-3.1.4/docs/cse3_1/TEMPLATE_ANNOUNCEMENTS.md <==
---
layout: default
title: Template Announcements
---
# Template Announcements

## October 14, 2021

**Highlights**

* Photon OS 2.0 templates are deprecated and will be removed in an upcoming CSE release.

All available templates:

| Template Name                        | Revision | Operating System  | Kubernetes  | Weave     | Docker                  |
|--------------------------------------|----------|-------------------|-------------|-----------|-------------------------|
| ubuntu-16.04_k8-1.21_weave-2.8.1     | 1        | Ubuntu-16.04      | 1.21.2      | 2.8.1     | Docker-ce 20.10.7       |
| ubuntu-16.04_k8-1.20_weave-2.6.5     | 2        | Ubuntu-16.04      | 1.20.6      | 2.6.5     | Docker-ce 19.03.15      |
| ubuntu-16.04_k8-1.19_weave-2.6.5     | 2        | Ubuntu-16.04      | 1.19.3      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.18_weave-2.6.5 *   | 2        | Ubuntu-16.04      | 1.18.6      | 2.6.5     | Docker-ce 19.03.12      |
| photon-v2_k8-1.14_weave-2.5.2 *      | 3        | Photon OS 2.0     | 1.14.10     | 2.5.2     | Docker-ce 18.06.2-6     |

* New templates are highlighted
* Updated template revisions are highlighted
* Removed templates are striked out
* Templates marked with '*' are deprecated and will be removed in future update.


## Jul 2, 2021

All templates currently available:
* New templates are highlighted
* Updated template revisions are highlighted
* Removed templates are striked out

| Template Name                        | Revision | Operating System  | Kubernetes  | Weave     | Docker                  |
|--------------------------------------|----------|-------------------|-------------|-----------|-------------------------|
| **ubuntu-16.04_k8-1.21_weave-2.8.1** | 1        | Ubuntu-16.04      | 1.21.2      | 2.8.1     | Docker-ce 20.10.7       |
| ubuntu-16.04_k8-1.20_weave-2.6.5     | **2**    | Ubuntu-16.04      | 1.20.6      | 2.6.5     | Docker-ce 19.03.15      |
| ubuntu-16.04_k8-1.19_weave-2.6.5     | **2**    | Ubuntu-16.04      | 1.19.3      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.18_weave-2.6.5 *   | 2        | Ubuntu-16.04      | 1.18.6      | 2.6.5     | Docker-ce 19.03.12      |
| ~~ubuntu-16.04_k8-1.17_weave-2.6.0~~ | ~~2~~    | ~~Ubuntu 16.04~~  | ~~1.17.9~~  | ~~2.6.0~~ | ~~Docker-ce 19.03.5~~   |
| photon-v2_k8-1.14_weave-2.5.2        | 3        | Photon OS 2.0     | 1.14.10     | 2.5.2     | Docker-ce 18.06.2-6     |

Templates marked with '*' are deprecated and will be removed in future update.

## May 3, 2021

All templates currently available:
* New templates are highlighted
* Updated template revisions are highlighted
* Removed templates are striked out

| Template Name                        | Revision | Operating System  | Kubernetes  | Weave     | Docker                  |
|--------------------------------------|----------|-------------------|-------------|-----------|-------------------------|
| **ubuntu-16.04_k8-1.20_weave-2.6.5** | 1        | Ubuntu-16.04      | 1.20.6      | 2.6.5     | Docker-ce 19.03.15      |
| ubuntu-16.04_k8-1.19_weave-2.6.5     | 1        | Ubuntu-16.04      | 1.19.3      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.18_weave-2.6.5     | 1        | Ubuntu-16.04      | 1.18.6      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.17_weave-2.6.0 *   | 2        | Ubuntu 16.04      | 1.17.9      | 2.6.0     | Docker-ce 19.03.5       |
| ~~ubuntu-16.04_k8-1.16_weave-2.6.0~~ | ~~2~~    | ~~Ubuntu 16.04~~  | ~~1.16.13~~ | ~~2.6.0~~ | ~~Docker-ce 18.09.7~~   |
| photon-v2_k8-1.14_weave-2.5.2        | 3        | Photon OS 2.0     | 1.14.10     | 2.5.2     | Docker-ce 18.06.2-6     |

Templates marked with '*' are deprecated and will be removed in future update.

## December 10, 2020

All templates currently available:
* New templates are highlighted
* Updated template revisions are highlighted
* Removed templates are striked out

| Template Name                        | Revision | Operating System  | Kubernetes  | Weave     | Docker                  |
|--------------------------------------|----------|-------------------|-------------|-----------|-------------------------|
| **ubuntu-16.04_k8-1.19_weave-2.6.5** | 1        | Ubuntu-16.04      | 1.19.3      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.18_weave-2.6.5     | 1        | Ubuntu-16.04      | 1.18.6      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.17_weave-2.6.0     | 2        | Ubuntu 16.04      | 1.17.9      | 2.6.0     | Docker-ce 19.03.5       |
| ubuntu-16.04_k8-1.16_weave-2.6.0 *   | 2        | Ubuntu 16.04      | 1.16.13     | 2.6.0     | Docker-ce 18.09.7       |
| ~~ubuntu-16.04_k8-1.15_weave-2.5.2~~ | ~~4~~    | ~~Ubuntu 16.04~~  | ~~1.15.12~~ | ~~2.5.2~~ | ~~Docker-ce 18.09.7~~   |
| photon-v2_k8-1.14_weave-2.5.2        | 3        | Photon OS 2.0     | 1.14.10     | 2.5.2     | Docker-ce 18.06.2-6     |

Templates marked with '*' are deprecated and will be removed in future update.

## October 08, 2020

All templates currently available:
* New templates are highlighted
* Updated template revisions are highlighted

| Template Name                        | Revision | Operating System  | Kubernetes  | Weave     | Docker                  |
|--------------------------------------|----------|-------------------|-------------|-----------|-------------------------|
| **ubuntu-16.04_k8-1.18_weave-2.6.5** | 1        | Ubuntu-16.04      | 1.18.6      | 2.6.5     | Docker-ce 19.03.12      |
| ubuntu-16.04_k8-1.17_weave-2.6.0     | **2**    | Ubuntu 16.04      | 1.17.9      | 2.6.0     | Docker-ce 19.03.5       |
| ubuntu-16.04_k8-1.16_weave-2.6.0     | **2**    | Ubuntu 16.04      | 1.16.13     | 2.6.0     | Docker-ce 18.09.7       |
| ubuntu-16.04_k8-1.15_weave-2.5.2 *     | **4**    | Ubuntu 16.04      | 1.15.12     | 2.5.2     | Docker-ce 18.09.7       |
| photon-v2_k8-1.14_weave-2.5.2        | **3**    | Photon OS 2.0     | 1.14.10      | 2.5.2    | Docker-ce 18.06.2-6     |

Templates marked with '*' are deprecated and will be removed in future update.

## March 09, 2020

All templates currently available:
* New templates are highlighted
* Updated template revisions are highlighted
* Removed templates are striked out

| Template Name                        | Revision | Operating System  | Kubernetes  | Weave     | Docker                  |
|--------------------------------------|----------|-------------------|-------------|-----------|-------------------------|
| **ubuntu-16.04_k8-1.17_weave-2.6.0** | 1        | Ubuntu 16.04      | 1.17.2      | 2.6.0     | Docker-ce 18.09.7       |
| **ubuntu-16.04_k8-1.16_weave-2.6.0** | 1        | Ubuntu 16.04      | 1.16.6      | 2.6.0     | Docker-ce 18.09.7       |
| ubuntu-16.04_k8-1.15_weave-2.5.2     | **3**    | Ubuntu 16.04      | 1.15.9      | 2.5.2     | Docker-ce 18.09.7       |
| photon-v2_k8-1.14_weave-2.5.2        | **2**    | Photon OS 2.0     | 1.14.6      | 2.5.2     | Docker-ce 18.06.2-3     |
|                                      |          |                   |             |           |                         |
| ~~ubuntu-16.04_k8-1.13_weave-2.3.0~~ | ~~3~~    | ~~Ubuntu 16.04~~  | ~~1.13.12~~ | ~~2.3.0~~ | ~~Docker-ce 18.09.7~~   |
| ~~photon-v2_k8-1.12_weave-2.3.0~~    | ~~2~~    | ~~Photon OS 2.0~~ | ~~1.12.7~~  | ~~2.3.0~~ | ~~Docker-ce 18.06.2-3~~ |


## February 05, 2020

These templates are exclusively for CSE 2.6.0 Beta.

| Template Name                    | Revision | Operating System | Kubernetes | Weave | Docker              |
|----------------------------------|----------|------------------|------------|-------|---------------------|
| photon-v2_k8-1.14_weave-2.5.2    | 2        | Photon OS 2.0    | 1.14.6     | 2.5.2 | Docker-ce 18.06.2-3 |
| photon-v2_k8-1.12_weave-2.3.0    | 2        | Photon OS 2.0    | 1.12.7     | 2.3.0 | Docker-ce 18.06.2-3 |
| ubuntu-16.04_k8-1.16_weave-2.6.0 | 1        | Ubuntu 16.04     | 1.16.6     | 2.6.0 | Docker-ce 18.09.7   |
| ubuntu-16.04_k8-1.15_weave-2.5.2 | 3        | Ubuntu 16.04     | 1.15.9     | 2.5.2 | Docker-ce 18.09.7   |
| ubuntu-16.04_k8-1.13_weave-2.3.0 | 3        | Ubuntu 16.04     | 1.13.12    | 2.3.0 | Docker-ce 18.09.7   |

## October 23, 2019

All templates currently available (updated/new templates are highlighted):

| Template Name                        | Revision | Operating System | Kubernetes | Weave | Docker              |
|--------------------------------------|----------|------------------|------------|-------|---------------------|
| **photon-v2_k8-1.14_weave-2.5.2**    | 1        | Photon OS 2.0    | 1.14.6     | 2.5.2 | Docker-ce 18.06.2-3 |
| photon-v2_k8-1.12_weave-2.3.0        | 1        | Photon OS 2.0    | 1.12.7     | 2.3.0 | Docker-ce 18.06.2-3 |
| **ubuntu-16.04_k8-1.15_weave-2.5.2** | 2        | Ubuntu 16.04     | 1.15.5     | 2.5.2 | Docker-ce 18.09.7   |
| **ubuntu-16.04_k8-1.13_weave-2.3.0** | 2        | Ubuntu 16.04     | 1.13.12    | 2.3.0 | Docker-ce 18.09.7   |

## October 3, 2019

All templates currently available (updated/new templates are highlighted):

| Template Name                    | Revision | Operating System | Kubernetes | Weave | Docker              |
|----------------------------------|----------|------------------|------------|-------|---------------------|
| photon-v2_k8-1.12_weave-2.3.0    | 1        | Photon OS 2.0    | 1.12.7     | 2.3.0 | Docker-ce 18.06.2-3 |
| ubuntu-16.04_k8-1.15_weave-2.5.2 | 1        | Ubuntu 16.04     | 1.15.3     | 2.5.2 | Docker-ce 18.09.7   |
| ubuntu-16.04_k8-1.13_weave-2.3.0 | 1        | Ubuntu 16.04     | 1.13.5     | 2.3.0 | Docker-ce 18.09.7   |
